Snap for 7867461 from 13d4feda1cb63a8a720b2e7dca4b27de01faeb17 to sc-v2-release

Change-Id: Ie3aa779f0723de82f057a1e4dab70661d34e1f16
diff --git a/test/cts/device_feature_test_cts.cc b/test/cts/device_feature_test_cts.cc
index 3ed5bc1..6ed16c3 100644
--- a/test/cts/device_feature_test_cts.cc
+++ b/test/cts/device_feature_test_cts.cc
@@ -21,9 +21,9 @@
 namespace perfetto {
 
 TEST(PerfettoDeviceFeatureTest, TestMaxCpusForAtraceChmod) {
   // Check that there are no more than 16 CPUs so that the assumption in the
   // atrace.rc for clearing CPU buffers is valid.
-  ASSERT_LE(sysconf(_SC_NPROCESSORS_CONF), 16);
+  ASSERT_LE(sysconf(_SC_NPROCESSORS_CONF), 24);
 }
 
 }  // namespace perfetto
@@ -21,9 +21,9 @@
 
 TEST(PerfettoDeviceFeatureTest, TestMaxCpusForAtraceChmod) {
-  // Check that there are no more than 16 CPUs so that the assumption in the
+  // Check that there are no more than 24 CPUs so that the assumption in the
   // atrace.rc for clearing CPU buffers is valid.